@@ -408,6 +408,16 @@ public class Generator
               facadeHelper.setCompilerCompliance("18"); 
               break;
             }
+            case JDK190_LITERAL:
+            {
+              facadeHelper.setCompilerCompliance("19"); 
+              break;
+            }
+            case JDK200_LITERAL:
+            {
+              facadeHelper.setCompilerCompliance("20"); 
+              break;
+            }
           }
 
           if (genModel.isCodeFormatting())
