@@ -1,9 +1,9 @@
 /**
  * Copyright (c) 2002-2009 IBM Corporation and others.
  * All rights reserved.   This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * http://www.eclipse.org/legal/epl-v20.html
  * 
  * Contributors: 
  *   IBM - Initial API and implementation
@@ -342,7 +342,7 @@ public class BasicEList<E> extends AbstractEList<E> implements RandomAccess, Clo
   @Override
   public E get(int index) 
   {
-    if (index >= size)
+    if (data == null || index >= size)
       throw new BasicIndexOutOfBoundsException(index, size);
 
     return resolve(index, (E)data[index]);
@@ -359,7 +359,7 @@ public class BasicEList<E> extends AbstractEList<E> implements RandomAccess, Clo
   @Override
   public E basicGet(int index)
   {
-    if (index >= size)
+    if (data == null || index >= size)
       throw new BasicIndexOutOfBoundsException(index, size);
 
     return primitiveGet(index);
@@ -404,7 +404,6 @@ public class BasicEList<E> extends AbstractEList<E> implements RandomAccess, Clo
    * Adds the object at the end of the list;
    * it does no uniqueness checking.
    * This implementation delegates to {@link #assign assign}, {@link #didAdd didAdd}, and {@link #didChange didChange}.
-   * after uniqueness checking.
    * @param object the object to be added.
    * @see #add(Object)
    */
@@ -749,7 +748,7 @@ public class BasicEList<E> extends AbstractEList<E> implements RandomAccess, Clo
     }
   }
 
-  private synchronized void readObject(ObjectInputStream objectInputStream) throws IOException, ClassNotFoundException
+  private void readObject(ObjectInputStream objectInputStream) throws IOException, ClassNotFoundException
   {
     objectInputStream.defaultReadObject();
     int arrayLength = objectInputStream.readInt();
