@@ -1,9 +1,9 @@
 /**
  * Copyright (c) 2005-2007 IBM Corporation and others.
  * All rights reserved.   This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * http://www.eclipse.org/legal/epl-v20.html
  * 
  * Contributors: 
  *   IBM - Initial API and implementation
@@ -18,6 +18,7 @@ import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
+import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
@@ -36,8 +37,8 @@ import org.eclipse.jface.viewers.ILabelProvider;
 import org.eclipse.jface.viewers.StructuredSelection;
 import org.eclipse.jface.viewers.TableLayout;
 import org.eclipse.jface.viewers.Viewer;
+import org.eclipse.jface.viewers.ViewerComparator;
 import org.eclipse.jface.viewers.ViewerFilter;
-import org.eclipse.jface.viewers.ViewerSorter;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.custom.SashForm;
 import org.eclipse.swt.events.ModifyEvent;
@@ -83,6 +84,7 @@ import org.eclipse.emf.ecore.EPackage;
 import org.eclipse.emf.ecore.EStructuralFeature;
 import org.eclipse.emf.ecore.resource.Resource;
 import org.eclipse.emf.ecore.resource.ResourceSet;
+import org.eclipse.emf.ecore.util.EcoreUtil;
 import org.eclipse.emf.edit.provider.ItemProvider;
 import org.eclipse.emf.edit.ui.provider.AdapterFactoryContentProvider;
 import org.eclipse.emf.edit.ui.provider.AdapterFactoryLabelProvider;
@@ -604,7 +606,7 @@ public class ModelConverterPackagePage extends ModelConverterPage
       };
 
     // Sorting only the genModels
-    referencedGenModelsTreeViewer.setSorter(new ViewerSorter()
+    referencedGenModelsTreeViewer.setComparator(new ViewerComparator()
       {
         @Override
         public void sort(Viewer viewer, Object[] elements)
@@ -667,8 +669,8 @@ public class ModelConverterPackagePage extends ModelConverterPage
         boolean plugin = uri.isPlatformPlugin();
         if (plugin || uri.isPlatformResource())
         {
-          String segment = URI.decode(uri.segment(1));
-          location = ConverterPlugin.INSTANCE.getString(plugin ? "_UI_PlatformPlugin_label" : "_UI_PlatformResource_label", new String[]{segment});
+          String path = uri.toPlatformString(true);
+          location = ConverterPlugin.INSTANCE.getString(plugin ? "_UI_PlatformPlugin_label" : "_UI_PlatformResource_label", new String[]{path});
         }
         return ConverterPlugin.INSTANCE.getString("_UI_ReferencedGenModel_label", new Object [] { defaultText, location });
       }
@@ -740,7 +742,8 @@ public class ModelConverterPackagePage extends ModelConverterPage
         {
           IFile file = (IFile)element;
           URI uri = URI.createPlatformResourceURI(file.getFullPath().toString(), true);
-          return "genmodel".equals(file.getFileExtension())
+          String fileExtension = file.getFileExtension();
+          return ("genmodel".equals(fileExtension) || "xcore".equals(fileExtension))
             && !file.getFullPath().equals(genModelPath)
             && !genModelURIs.contains(uri);
         }
@@ -762,7 +765,7 @@ public class ModelConverterPackagePage extends ModelConverterPage
       {
         URI genModelURI = URI.createPlatformResourceURI(files[i].getFullPath().toString(), true);
         Resource genModelResource = referencedGenModels.getResource(genModelURI, true);
-        GenModel genModel = (GenModel)genModelResource.getContents().get(0);
+        GenModel genModel = (GenModel)EcoreUtil.getObjectByType(genModelResource.getContents(), GenModelPackage.Literals.GEN_MODEL);
         genModels.add(genModel);
       }
       
@@ -897,9 +900,24 @@ public class ModelConverterPackagePage extends ModelConverterPage
       {
         if (!getModelConverter().getReferencedGenPackages().isEmpty() || !getModelConverter().getExternalGenModels().isEmpty())
         {
+          // Check for duplicates that would result in an error message in the dialog.
+          Map<String, GenPackage> uniqueGenPackages = new LinkedHashMap<String, GenPackage>();
+          List<GenPackage> referencedGenPackages = getModelConverter().getReferencedGenPackages();
+          for (GenPackage genPackage : referencedGenPackages)
+          {
+            String nsURI = genPackage.getEcorePackage().getNsURI();
+            GenPackage otherGenPackage = uniqueGenPackages.put(nsURI, genPackage);
+            // Prefer the *.genmodel over any alternative.
+            if (otherGenPackage != null && "genmodel".equals(otherGenPackage.eResource().getURI().fileExtension()))
+            {
+              uniqueGenPackages.put(nsURI, otherGenPackage);
+            }
+          }
+          referencedGenPackages.retainAll(uniqueGenPackages.values());
+
           List<GenModel> genModels = new UniqueEList.FastCompare<GenModel>();
           genPackagesToCheck = new ConverterUtil.GenPackageList();
-          for (GenPackage genPackage : getModelConverter().getReferencedGenPackages())
+          for (GenPackage genPackage : referencedGenPackages)
           {
             genModels.add(genPackage.getGenModel());
             ModelConverter.ReferencedGenPackageConvertInfo genPackageInfo = 
