@@ -1,9 +1,9 @@
 /**
  * Copyright (c) 2002-2007 IBM Corporation and others.
  * All rights reserved.   This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * http://www.eclipse.org/legal/epl-v20.html
  * 
  * Contributors: 
  *   IBM - Initial API and implementation
@@ -26,6 +26,7 @@ import java.util.List;
 
 import org.eclipse.jface.resource.CompositeImageDescriptor;
 import org.eclipse.jface.resource.ImageDescriptor;
+import org.eclipse.swt.graphics.Device;
 import org.eclipse.swt.graphics.Image;
 import org.eclipse.swt.graphics.ImageData;
 import org.eclipse.swt.graphics.Point;
@@ -51,16 +52,37 @@ public class ExtendedImageRegistry
     return INSTANCE;
   }
 
+  protected final Display display;
+
   protected HashMap<Object, Image> table = new HashMap<Object, Image>(10);
 
+  protected HashMap<Object, ImageDescriptor> imageDescriptorTable = new HashMap<Object, ImageDescriptor>(10);
+
   public ExtendedImageRegistry() 
   {
     Display display = Display.getCurrent();
-    hookDisplayDispose(display);
+    if (display == null)
+    {
+      final Display defaultDisplay= Display.getDefault();
+      defaultDisplay.asyncExec
+        (new Runnable()
+         {
+           public void run()
+           {
+             hookDisplayDispose(defaultDisplay);
+           }
+         });
+      this.display = defaultDisplay;
+    }
+    else
+    {
+      this.display = display;
+    }
   }
 
   public ExtendedImageRegistry(Display display) 
   {
+    this.display = display;
     hookDisplayDispose(display);
   }
 
@@ -167,20 +189,18 @@ public class ExtendedImageRegistry
         {
           table.put(object, result);
         }
-
       }
       return result;
     }
   }
 
-
   public ImageDescriptor getImageDescriptor(Object object) 
   {
     if (object instanceof ImageDescriptor)
     {
       return (ImageDescriptor)object;
     }
-    else
+    else if (display == Display.getCurrent())
     {
       final Image image = getImage(object);
       if (image != null)
@@ -192,6 +212,108 @@ public class ExtendedImageRegistry
         return null;
       }
     }
+    else
+    {
+      return getImageDescriptorOnBackgroundThread(object);
+    }
+  }
+
+  protected synchronized ImageDescriptor getImageDescriptorOnBackgroundThread(Object object) 
+  {
+    if (object instanceof ImageDescriptor)
+    {
+      return (ImageDescriptor)object;
+    }
+    else
+    {
+      ImageDescriptor result = imageDescriptorTable.get(object);
+      if (result == null)
+      {
+        if (object instanceof Image)
+        {
+          result = new ImageWrapperImageDescriptor((Image)object);
+        }
+        else
+        {
+          Image image = table.get(object);
+          if (image != null)
+          {
+            result = new ImageWrapperImageDescriptor(image);
+          }
+          else if (object instanceof URL || object instanceof URI)
+          {
+            String urlString = object.toString(); 
+            if (urlString.startsWith(resourceURLPrefix))
+            {
+              if (EMFPlugin.IS_RESOURCES_BUNDLE_AVAILABLE)
+              {
+                result = 
+                  PlatformUI.getWorkbench().getEditorRegistry().getImageDescriptor 
+                    ("dummy." + urlString.substring(resourceURLPrefix.length()));
+              }
+              else
+              {
+                result = getImageDescriptor(resourceURL);
+              }
+            }
+            else if (urlString.startsWith(itemURLPrefix))
+            {
+              try
+              {
+                URL url = new URL(urlString.substring(0, itemURLPrefix.length()));
+                String key1 = urlString.substring(itemURLPrefix.length());
+                result = new URLImageDescriptor(url, key1, null);
+              }
+              catch (IOException exception)
+              {
+                // Ignore
+              }
+            }
+            else if (urlString.startsWith(createChildURLPrefix))
+            {
+              try
+              {
+                URL url = new URL(urlString.substring(0, createChildURLPrefix.length()));
+                String key1 = urlString.substring(createChildURLPrefix.length() + 1);
+                String key2 = null;
+                int index = key1.indexOf("/");
+                if (index != -1)
+                {
+                  key2 =  key1.substring(index + 1);
+                  key1 =  key1.substring(0, index);
+                }
+                result = new URLImageDescriptor(url, key1, key2);
+              }
+              catch (IOException exception)
+              {
+                // Ignore
+              }
+            }
+            else
+            {
+              try
+              {
+                result = ImageDescriptor.createFromURL(new URL(urlString));
+              }
+              catch (IOException exception)
+              {
+                // Ignore
+              }
+            }
+          }
+          else if (object instanceof ComposedImage)
+          {
+            result = new ComposedImageDescriptor((ComposedImage)object);
+          }
+        }
+
+        if (result != null)
+        {
+          imageDescriptorTable.put(object,  result);
+        }
+      }
+      return result;
+    }
   }
 
   protected void handleDisplayDispose() 
@@ -259,6 +381,7 @@ class ComposedImageDescriptor extends CompositeImageDescriptor
   }
 
   @Override
+  @SuppressWarnings("deprecation")
   public void drawCompositeImage(int width, int height)
   {
     ComposedImage.Size size = new ComposedImage.Size();
@@ -374,6 +497,14 @@ class URLImageDescriptor extends ImageDescriptor
       return false;
     }
   }
+  
+  @Override
+  public Image createImage(boolean returnMissingImageOnError, Device device)
+  {
+    // Don't call super because it loses the transparency information if we write this image to disk.
+    //
+    return new Image(device, getImageData());
+  }
 
   @Override
   public String toString() 
