@@ -1,9 +1,9 @@
 /**
  * Copyright (c) 2006 IBM Corporation and others.
  * All rights reserved.   This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * http://www.eclipse.org/legal/epl-v20.html
  *
  * Contributors:
  *   IBM - Initial API and implementation
@@ -58,9 +58,6 @@ import org.eclipse.emf.edit.ui.util.EditUIMarkerHelper;
 import org.eclipse.emf.edit.ui.util.EditUIUtil;
 import org.eclipse.emf.edit.ui.view.ExtendedPropertySheetPage;
 
-import org.eclipse.emf.ecore.EObject;
-import org.eclipse.emf.ecore.EValidator;
-
 import org.eclipse.emf.ecore.resource.Resource;
 import org.eclipse.emf.ecore.resource.ResourceSet;
 
@@ -104,6 +101,7 @@ import org.eclipse.jface.action.Separator;
 import org.eclipse.jface.dialogs.MessageDialog;
 import org.eclipse.jface.dialogs.ProgressMonitorDialog;
 
+import org.eclipse.jface.util.LocalSelectionTransfer;
 import org.eclipse.jface.viewers.ColumnWeightData;
 import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.jface.viewers.ISelectionChangedListener;
@@ -123,6 +121,7 @@ import org.eclipse.swt.SWT;
 import org.eclipse.swt.custom.CTabFolder;
 
 import org.eclipse.swt.dnd.DND;
+import org.eclipse.swt.dnd.FileTransfer;
 import org.eclipse.swt.dnd.Transfer;
 
 import org.eclipse.swt.events.ControlAdapter;
@@ -234,7 +233,7 @@ public class Ecore2XMLEditor
    * <!-- end-user-doc -->
    * @generated
    */
-  protected PropertySheetPage propertySheetPage;
+  protected List<PropertySheetPage> propertySheetPages = new ArrayList<PropertySheetPage>();
 
   /**
    * This is the viewer that shadows the selection in the content outline.
@@ -358,7 +357,7 @@ public class Ecore2XMLEditor
         }
         else if (p instanceof PropertySheet)
         {
-          if (((PropertySheet)p).getCurrentPage() == propertySheetPage)
+          if (propertySheetPages.contains(((PropertySheet)p).getCurrentPage()))
           {
             getActionBarContributor().setActiveEditor(Ecore2XMLEditor.this);
             handleActivate();
@@ -483,6 +482,18 @@ public class Ecore2XMLEditor
       protected void unsetTarget(Resource target)
       {
         basicUnsetTarget(target);
+        resourceToDiagnosticMap.remove(target);
+        if (updateProblemIndication)
+        {
+          getSite().getShell().getDisplay().asyncExec
+            (new Runnable()
+             {
+               public void run()
+               {
+                 updateProblemIndication();
+               }
+             });
+        }
       }
     };
 
@@ -526,6 +537,7 @@ public class Ecore2XMLEditor
                     }
                   }
                 }
+                return false;
               }
 
               return true;
@@ -680,7 +692,7 @@ public class Ecore2XMLEditor
       BasicDiagnostic diagnostic =
         new BasicDiagnostic
           (Diagnostic.OK,
-           "org.eclipse.emf.mapping.ecore2xml.edit", //$NON-NLS-1$
+           "org.eclipse.emf.mapping.ecore2xml.ui", //$NON-NLS-1$
            0,
            null,
            new Object [] { editingDomain.getResourceSet() });
@@ -804,9 +816,17 @@ public class Ecore2XMLEditor
                   {
                     setSelectionToViewer(mostRecentCommand.getAffectedObjects());
                   }
-                  if (propertySheetPage != null && !propertySheetPage.getControl().isDisposed())
+                  for (Iterator<PropertySheetPage> i = propertySheetPages.iterator(); i.hasNext(); )
                   {
-                    propertySheetPage.refresh();
+                    PropertySheetPage propertySheetPage = i.next();
+                    if (propertySheetPage.getControl() == null || propertySheetPage.getControl().isDisposed())
+                    {
+                      i.remove();
+                    }
+                    else
+                    {
+                      propertySheetPage.refresh();
+                    }
                   }
                 }
               });
@@ -1037,7 +1057,7 @@ public class Ecore2XMLEditor
     getSite().registerContextMenu(contextMenu, new UnwrappingSelectionProvider(viewer));
 
     int dndOperations = DND.DROP_COPY | DND.DROP_MOVE | DND.DROP_LINK;
-    Transfer[] transfers = new Transfer[] { LocalTransfer.getInstance() };
+    Transfer[] transfers = new Transfer[] { LocalTransfer.getInstance(), LocalSelectionTransfer.getTransfer(), FileTransfer.getInstance() };
     viewer.addDragSupport(dndOperations, transfers, new ViewerDragAdapter(viewer));
     viewer.addDropSupport(dndOperations, transfers, new EditingDomainViewerDropAdapter(editingDomain, viewer));
   }
@@ -1082,12 +1102,13 @@ public class Ecore2XMLEditor
    */
   public Diagnostic analyzeResourceProblems(Resource resource, Exception exception) 
   {
-    if (!resource.getErrors().isEmpty() || !resource.getWarnings().isEmpty())
+    boolean hasErrors = !resource.getErrors().isEmpty();
+    if (hasErrors || !resource.getWarnings().isEmpty())
     {
       BasicDiagnostic basicDiagnostic =
         new BasicDiagnostic
-          (Diagnostic.ERROR,
-           "org.eclipse.emf.mapping.ecore2xml.edit", //$NON-NLS-1$
+          (hasErrors ? Diagnostic.ERROR : Diagnostic.WARNING,
+           "org.eclipse.emf.mapping.ecore2xml.ui", //$NON-NLS-1$
            0,
            getString("_UI_CreateModelError_message", resource.getURI()), //$NON-NLS-1$
            new Object [] { exception == null ? (Object)resource : exception });
@@ -1099,7 +1120,7 @@ public class Ecore2XMLEditor
       return
         new BasicDiagnostic
           (Diagnostic.ERROR,
-           "org.eclipse.emf.mapping.ecore2xml.edit", //$NON-NLS-1$
+           "org.eclipse.emf.mapping.ecore2xml.ui", //$NON-NLS-1$
            0,
            getString("_UI_CreateModelError_message", resource.getURI()), //$NON-NLS-1$
            new Object[] { exception });
@@ -1450,7 +1471,7 @@ public class Ecore2XMLEditor
    * <!-- end-user-doc -->
    * @generated
    */
-  @SuppressWarnings("rawtypes")
+  @SuppressWarnings({ "rawtypes", "unchecked" })
   @Override
   public Object getAdapter(Class key)
   {
@@ -1553,27 +1574,25 @@ public class Ecore2XMLEditor
    */
   public IPropertySheetPage getPropertySheetPage()
   {
-    if (propertySheetPage == null)
-    {
-      propertySheetPage =
-        new ExtendedPropertySheetPage(editingDomain)
+    PropertySheetPage propertySheetPage =
+      new ExtendedPropertySheetPage(editingDomain)
+      {
+        @Override
+        public void setSelectionToViewer(List<?> selection)
         {
-          @Override
-          public void setSelectionToViewer(List<?> selection)
-          {
-            Ecore2XMLEditor.this.setSelectionToViewer(selection);
-            Ecore2XMLEditor.this.setFocus();
-          }
+          Ecore2XMLEditor.this.setSelectionToViewer(selection);
+          Ecore2XMLEditor.this.setFocus();
+        }
 
-          @Override
-          public void setActionBars(IActionBars actionBars)
-          {
-            super.setActionBars(actionBars);
-            getActionBarContributor().shareGlobalActions(this, actionBars);
-          }
-        };
-      propertySheetPage.setPropertySourceProvider(new AdapterFactoryContentProvider(adapterFactory));
-    }
+        @Override
+        public void setActionBars(IActionBars actionBars)
+        {
+          super.setActionBars(actionBars);
+          getActionBarContributor().shareGlobalActions(this, actionBars);
+        }
+      };
+    propertySheetPage.setPropertySourceProvider(new AdapterFactoryContentProvider(adapterFactory));
+    propertySheetPages.add(propertySheetPage);
 
     return propertySheetPage;
   }
@@ -1649,6 +1668,7 @@ public class Ecore2XMLEditor
     //
     final Map<Object, Object> saveOptions = new HashMap<Object, Object>();
     saveOptions.put(Resource.OPTION_SAVE_ONLY_IF_CHANGED, Resource.OPTION_SAVE_ONLY_IF_CHANGED_MEMORY_BUFFER);
+    saveOptions.put(Resource.OPTION_LINE_DELIMITER, Resource.OPTION_LINE_DELIMITER_UNSPECIFIED);
 
     // Do the work within an operation because this is a long running activity that modifies the workbench.
     //
@@ -1710,7 +1730,7 @@ public class Ecore2XMLEditor
 
   /**
    * This returns whether something has been persisted to the URI of the specified resource.
-   * The implementation uses the URI converter from the editor's resource set to try to open an input stream. 
+   * The implementation uses the URI converter from the editor's resource set to try to open an input stream.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @generated
@@ -1792,25 +1812,10 @@ public class Ecore2XMLEditor
    */
   public void gotoMarker(IMarker marker)
   {
-    try
+    List<?> targetObjects = markerHelper.getTargetObjects(editingDomain, marker);
+    if (!targetObjects.isEmpty())
     {
-      if (marker.getType().equals(EValidator.MARKER))
-      {
-        String uriAttribute = marker.getAttribute(EValidator.URI_ATTRIBUTE, null);
-        if (uriAttribute != null)
-        {
-          URI uri = URI.createURI(uriAttribute);
-          EObject eObject = editingDomain.getResourceSet().getEObject(uri, true);
-          if (eObject != null)
-          {
-            setSelectionToViewer(Collections.singleton(editingDomain.getWrapper(eObject)));
-          }
-        }
-      }
-    }
-    catch (CoreException exception)
-    {
-      Ecore2XMLUIPlugin.INSTANCE.log(exception);
+      setSelectionToViewer(targetObjects);
     }
   }
 
@@ -2026,7 +2031,7 @@ public class Ecore2XMLEditor
       getActionBarContributor().setActiveEditor(null);
     }
 
-    if (propertySheetPage != null)
+    for (PropertySheetPage propertySheetPage : propertySheetPages)
     {
       propertySheetPage.dispose();
     }
