@@ -28,7 +28,7 @@ import org.junit.runners.MethodSorters;
  * <p>
  * This test class is more than just a test.
  * It is used to maintain, update, and manage the integrity of EMF's public update site:
- * <pre><a href="http://download.eclipse.org/modeling/emf/emf/builds/index.html">http://download.eclipse.org/modeling/emf/emf/builds/index.html</a></pre>
+ * <pre><a href="https://download.eclipse.org/modeling/emf/emf/builds/index.html">https://download.eclipse.org/modeling/emf/emf/builds/index.html</a></pre>
  * It can also be used locally to test the promotion process.
  * The physical file location that will be updated by these tests is rooted at at {@link UpdateSiteGenerator#BUILDS_ROOT_FOLDER}.
  * </p>
@@ -78,11 +78,6 @@ public class UpdateSiteGeneratorTest
   @Test
   public void step01PromoteUpdateSite() throws Exception
   {
-    String userDir = System.getProperty("user.dir");
-    String sourceRepository = UpdateSiteGenerator.getCanonicalPath(new File(userDir, "../org.eclipse.emf.site/target/repository"));
-    System.out.println("sourceRepository=" + sourceRepository);
-    Assert.assertTrue("Update site is invalid: " + sourceRepository, new File(sourceRepository, "content.jar").isFile());
-
     String buildTimestamp = System.getProperty("publish.build.timestamp");
     Assert.assertNotNull("publish.build.timestamp is null", buildTimestamp);
     try
@@ -106,6 +101,11 @@ public class UpdateSiteGeneratorTest
     Assume.assumeTrue("true".equals(System.getProperty("publish.repository")));
     Assume.assumeTrue(!"release".equals(System.getProperty("publish.build.type")));
 
+    String userDir = System.getProperty("user.dir");
+    String sourceRepository = UpdateSiteGenerator.getCanonicalPath(new File(userDir, "../org.eclipse.emf.site/target/repository"));
+    System.out.println("sourceRepository=" + sourceRepository);
+    Assert.assertTrue("Update site is invalid: " + sourceRepository, new File(sourceRepository, "content.jar").isFile());
+
     UpdateSiteGenerator updateSiteGenerator = new UpdateSiteGenerator();
     System.out.println("Promoting update site to " + updateSiteGenerator.getPromoteUpdateSiteDestination(buildType, buildTimestamp));
     File promotedUpdateSite = updateSiteGenerator.promoteUpdateSite(sourceRepository, buildType, buildTimestamp);
@@ -155,7 +155,7 @@ public class UpdateSiteGeneratorTest
     Assume.assumeTrue("release".equals(System.getProperty("publish.build.type")));
 
     UpdateSiteGenerator updateSiteGenerator = new UpdateSiteGenerator();
-    String source = UpdateSiteGenerator.BUILDS_ROOT_FOLDER + "/milestone/latest";
+    String source = updateSiteGenerator.getFirstChild(UpdateSiteGenerator.BUILDS_ROOT_FOLDER + "/milestone/latest");
     String version = updateSiteGenerator.getVersion(source);
     final String destination = updateSiteGenerator.getPromoteUpdateSiteDestination("release", version);
     Assert.assertFalse("The release '" + destination + "' already exists", new File(destination).exists());
