@@ -10,13 +10,20 @@
  */
 package org.eclipse.emf.test.databinding;
 
+
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertSame;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+
 import java.util.Arrays;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
-import junit.framework.TestCase;
-
 import org.eclipse.core.databinding.observable.Realm;
 import org.eclipse.core.databinding.observable.list.IListChangeListener;
 import org.eclipse.core.databinding.observable.list.IObservableList;
@@ -31,11 +38,13 @@ import org.eclipse.core.databinding.observable.set.ISetChangeListener;
 import org.eclipse.core.databinding.observable.set.SetChangeEvent;
 import org.eclipse.core.databinding.observable.set.SetDiff;
 import org.eclipse.core.databinding.observable.value.IObservableValue;
+import org.eclipse.emf.common.util.BasicEList;
+import org.eclipse.emf.common.util.EList;
 import org.eclipse.emf.common.util.URI;
 import org.eclipse.emf.databinding.EMFProperties;
+import org.eclipse.emf.databinding.FeaturePath;
 import org.eclipse.emf.databinding.IEMFListProperty;
 import org.eclipse.emf.databinding.IEMFListProperty.ListElementAccess;
-import org.eclipse.emf.databinding.FeaturePath;
 import org.eclipse.emf.databinding.IEMFMapProperty;
 import org.eclipse.emf.databinding.IEMFSetProperty;
 import org.eclipse.emf.databinding.IEMFValueProperty;
@@ -48,31 +57,32 @@ import org.eclipse.emf.test.databinding.emfdb.A;
 import org.eclipse.emf.test.databinding.emfdb.B;
 import org.eclipse.emf.test.databinding.emfdb.EmfdbFactory;
 import org.eclipse.emf.test.databinding.emfdb.EmfdbPackage;
+import org.junit.Before;
+import org.junit.Test;
 
 
-public class EMFPropertiesTest extends TestCase
+public class EMFPropertiesTest
 {
   private Resource resource;
+
   private Realm testRealm;
+
   private SetDiff setDiff;
+
   private ListDiff listDiff;
+
   private MapDiff mapDiff;
 
-  @Override
-  protected void setUp() throws Exception
+  @Before
+  public void setUp() throws Exception
   {
-    super.setUp();
-
     ResourceSet resourceSet = new ResourceSetImpl();
-    resourceSet.getResourceFactoryRegistry().getExtensionToFactoryMap().put(
-      Resource.Factory.Registry.DEFAULT_EXTENSION,
-      new XMIResourceFactoryImpl());
+    resourceSet.getResourceFactoryRegistry().getExtensionToFactoryMap().put(Resource.Factory.Registry.DEFAULT_EXTENSION, new XMIResourceFactoryImpl());
 
     URI uri = URI.createFileURI(TestUtil.getPluginDirectory("org.eclipse.emf.test.databinding") + "/model/A.xmi");
     resource = resourceSet.getResource(uri, true);
     testRealm = new Realm()
       {
-
         @Override
         public boolean isCurrent()
         {
@@ -81,6 +91,7 @@ public class EMFPropertiesTest extends TestCase
       };
   }
 
+  @Test
   public void testFeaturePath()
   {
     assertNotNull(FeaturePath.fromList(EmfdbPackage.Literals.A__BLIST));
@@ -95,6 +106,7 @@ public class EMFPropertiesTest extends TestCase
     }
   }
 
+  @Test
   public void testResourceProperty()
   {
     Realm.runWithDefault(testRealm, new Runnable()
@@ -113,7 +125,6 @@ public class EMFPropertiesTest extends TestCase
     IObservableList list = prop.observe(resource);
     list.addListChangeListener(new IListChangeListener()
       {
-
         public void handleListChange(ListChangeEvent event)
         {
           listDiff = event.diff;
@@ -188,11 +199,11 @@ public class EMFPropertiesTest extends TestCase
     assertEquals(2, listDiff.getDifferences().length);
   }
 
+  @Test
   public void testSetProperty()
   {
     Realm.runWithDefault(testRealm, new Runnable()
       {
-
         public void run()
         {
           _testSetProperty();
@@ -222,11 +233,11 @@ public class EMFPropertiesTest extends TestCase
     assertSame(b, setDiff.getAdditions().iterator().next());
   }
 
+  @Test
   public void testListPropertyOnSingleFeature()
   {
     Realm.runWithDefault(testRealm, new Runnable()
       {
-
         public void run()
         {
           _testListPropertyOnSingleFeature();
@@ -262,6 +273,7 @@ public class EMFPropertiesTest extends TestCase
     a.setString("Instance 1");
   }
 
+  @Test
   public void testListElementProperty()
   {
     Realm.runWithDefault(testRealm, new Runnable()
@@ -279,7 +291,6 @@ public class EMFPropertiesTest extends TestCase
     IEMFListProperty prop = EMFProperties.list(EmfdbPackage.Literals.A__BLIST);
     IEMFValueProperty valueProp = prop.value(new ListElementAccess<Object>()
       {
-
         @Override
         public int getReadValueIndex(List<Object> list)
         {
@@ -322,6 +333,7 @@ public class EMFPropertiesTest extends TestCase
     assertEquals("New Element 2", value.getValue());
   }
 
+  @Test
   public void testMapProperty()
   {
     Realm.runWithDefault(testRealm, new Runnable()
@@ -334,7 +346,6 @@ public class EMFPropertiesTest extends TestCase
       });
   }
 
-  @SuppressWarnings("unchecked")
   public void _testMapProperty()
   {
     A a = (A)resource.getContents().get(0);
@@ -342,7 +353,6 @@ public class EMFPropertiesTest extends TestCase
     IObservableMap map = prop.observe(a);
     map.addMapChangeListener(new IMapChangeListener()
       {
-
         public void handleMapChange(MapChangeEvent event)
         {
           mapDiff = event.diff;
@@ -439,16 +449,17 @@ public class EMFPropertiesTest extends TestCase
     map.clear();
   }
 
+  @Test
   public void test_sublistElement()
   {
     Realm.runWithDefault(testRealm, new Runnable()
-    {
-
-      public void run()
       {
-        _test_sublistElement();
-      }
-    });
+
+        public void run()
+        {
+          _test_sublistElement();
+        }
+      });
   }
 
   public void _test_sublistElement()
@@ -457,7 +468,7 @@ public class EMFPropertiesTest extends TestCase
     IEMFListProperty lProp1 = EMFProperties.list(EmfdbPackage.Literals.A__BLIST);
     IEMFValueProperty vProp1 = lProp1.value(new ListElementAccess<Object>()
       {
-
+        @Override
         public int getReadValueIndex(List<Object> list)
         {
           return 0;
@@ -472,10 +483,10 @@ public class EMFPropertiesTest extends TestCase
 
     IEMFValueProperty vProp2 = vProp1.value(EmfdbPackage.Literals.B__D);
     IEMFListProperty lProp2 = vProp2.list(EmfdbPackage.Literals.D__ELIST);
-        
+
     IEMFValueProperty vProp3 = lProp2.value(new ListElementAccess<Object>()
       {
-
+        @Override
         public int getReadValueIndex(List<Object> list)
         {
           return list.size() - 1;
@@ -487,10 +498,84 @@ public class EMFPropertiesTest extends TestCase
           return WriteData.NO_INDEX;
         }
       });
-    
 
     IEMFValueProperty detailValue = vProp3.value(EmfdbPackage.Literals.E__NAME);
     IObservableValue v = detailValue.observe(a);
     assertEquals(v.getValue(), "Last Element");
   }
+
+  @Test
+  public void test_attributeListWithDuplicates()
+  {
+    Realm.runWithDefault(testRealm, new Runnable()
+      {
+        public void run()
+        {
+          _test_attributeListWithDuplicates();
+        }
+      });
+  }
+
+  public void _test_attributeListWithDuplicates()
+  {
+    A a = (A)resource.getContents().get(0);
+    EList<String> strings = a.getStrings();
+
+    IEMFListProperty stringsListProperty = EMFProperties.list(EmfdbPackage.Literals.A__STRINGS);
+    IObservableList observableList = stringsListProperty.observe(a);
+    EList<String> normalList = new BasicEList<String>();
+
+    String value1 = "value1";
+    String value1Copy = new String(value1);
+    String value2 = "value2";
+    String value3 = "value3";
+
+    observableList.add(value1);
+    observableList.add(value2);
+    observableList.add(value1Copy);
+    observableList.add(3, value2);
+
+    normalList.add(value1);
+    normalList.add(value2);
+    normalList.add(value1Copy);
+    normalList.add(3, value2);
+
+    assertSameListContents(normalList, observableList);
+    assertSameListContents(normalList, strings);
+
+    observableList.set(2, value3);
+    normalList.set(2, value3);
+
+    assertSameListContents(normalList, observableList);
+    assertSameListContents(normalList, strings);
+
+    observableList.remove(2);
+    normalList.remove(2);
+
+    assertSameListContents(normalList, observableList);
+    assertSameListContents(normalList, strings);
+
+    // See https://bugs.eclipse.org/bugs/show_bug.cgi?id=478053 that 
+    //  EList.move(int, int) and 
+    //  IObservableList.move(int, int) 
+    // have opposite meaning for source and target.
+    //
+    observableList.move(2, 0);
+    normalList.move(0, 2);
+
+    assertSameListContents(normalList, observableList);
+    assertSameListContents(normalList, strings);
+  }
+
+  private void assertSameListContents(List<?> list1, List<?> list2)
+  {
+    String string1 = list1.toString();
+    String string2 = list2.toString();
+    assertEquals(string1, string2);
+    assertEquals(list1.size(), list2.size());
+    for (int i = 0, size = list1.size(); i < size; ++i)
+    {
+      assertSame("Same object expected at index " + i + " of " + string1, list1.get(i), list2.get(i));
+    }
+  }
 }
